==> escapework-manager-subscribers-0.5.0-211463.tar: src/views/subscribers/index.blade.php <==
@extends('manager::layouts.master')

@section('content')
    <ul class="breadcrumb">
        <li><a href="{{ route('manager.home') }}">Home</a> <span class="divider">/</span></li>
        <li class="active">Contatos da Newsletter</li>
    </ul><!-- .breadcrumb -->

    <div class="page-header">
        <div class="pull-left">
            <h3>Contatos da Newsletter</h3>
        </div><!-- .pull-left -->

        <div class="pull-right">
            @if (Check::can('subscribers', 'create'))
                <a href="{{ route('manager.subscribers.create') }}" class="btn btn-primary">Inserir novo contato</a>
                <a class="btn btn-info" href="{{ route('manager.subscribers.export') }}">Exportar Contatos</a>
            @endif
        </div><!-- .pull-right -->

        <div class="clearfix"></div>
    </div><!-- .page-header -->

    {{ Msg::getAll() }}

    @if (Check::can('subscribers', 'read'))
        <table class="table table-bordered table-striped table-hover">
            <thead>
                <tr>
                    <th>#</th>
                    <th>Nome</th>
                    <th>E-mail</th>
                    <th>Ações</th>
                </tr>
            </thead>
            <tbody>
                @foreach ($subscribers as $subscriber)
                    <tr>
                        <td>{{ $subscriber->id }}</td>
                        <td>{{ $subscriber->name }}</td>
                        <td>{{ $subscriber->email }}</td>
                        <td>
                            <div class="btn-group">
                                @if (Check::can('subscribers', 'update'))
                                    <a href="{{ route('manager.subscribers.edit', $subscriber->id) }}" class="btn btn-small" title="Editar">
                                        <i class="icon-pencil"></i> editar
                                    </a>
                                @endif

                                @if (Check::can('subscribers', 'destroy'))
                                    <a href="{{ route('manager.subscribers.destroy', $subscriber->id) }}" class="btn btn-small" title="Excluir" data-delete>
                                        <i class="icon-trash"></i> excluir
                                    </a>
                                @endif
                            </div>
                        </td>
                    </tr>
                @endforeach
            </tbody>
        </table>

        <div class="pull-left">
            {{ $subscribers->appends(Input::all())->links() }}
        </div><!-- .pull-left -->

        <div class="pull-right">
            <p>Exibindo resultados de {{ $subscribers->getFrom() }} até {{ $subscribers->getTo() }} de um total de {{ $subscribers->getTotal() }}</p>
        </div><!-- .pull-right -->

        <div class="clearfix"></div>
    @endif
@stop

==> escapework-manager-subscribers-0.7.0-7b96a8.tar: src/views/subscribers/index.blade.php <==
@extends('manager::layouts.master')

@section('content')
    <ul class="breadcrumb">
        <li><a href="{{ route('manager.home') }}">Home</a> <span class="divider">/</span></li>
        <li class="active">Contatos da Newsletter</li>
    </ul><!-- .breadcrumb -->

    <div class="page-header">
        <div class="pull-left">
            <h2>Contatos da Newsletter</h2>
        </div><!-- .pull-left -->

        <div class="pull-right">
            @if (Check::can('subscribers', 'create'))
                <a href="{{ route('manager.subscribers.create') }}" class="btn btn-primary">Inserir novo contato</a>
                <a class="btn btn-info" href="{{ route('manager.subscribers.export') }}">Exportar Contatos</a>
            @endif
        </div><!-- .pull-right -->

        <div class="clearfix"></div>
    </div><!-- .page-header -->

    {{ Msg::getAll() }}

    @if (Check::can('subscribers', 'read'))
        <form action="{{ route('manager.subscribers.index') }}" class="well form-inline" method="get" id="form-search">
            <div class="pull-left">
                <label>
                    <input type="text" name="name" placeholder="Nome..." value="{{ Input::get('name') }}" maxlength="100" />
                </label>&nbsp;
            </div>

            <div class="pull-left">
                <label>
                    <input type="text" name="email" placeholder="Email..." value="{{ Input::get('email') }}" maxlength="100" />
                </label>&nbsp;
            </div>

            <div class="pull-left">
                <button type="submit" class="btn btn-primary"><i class="icon-search icon-white"></i> Buscar</button>

                <a class="btn btn-primary" href="{{ route('manager.subscribers.index') }}">
                    Limpar filtros
                </a>
            </div>

            <div class="clearfix"></div>
        </form>

        <table class="table table-bordered table-striped table-hover">
            <thead>
                <tr>
                    <th>#</th>
                    <th><a href="{{ route('manager.subscribers.index', array('orderBy' => order_by('name'))) }}" title="Ordenar pelo nome">Nome</a></th>
                    <th><a href="{{ route('manager.subscribers.index', array('orderBy' => order_by('email'))) }}" title="Ordenar pelo e-mail">E-mail</a></th>
                    <th>Ações</th>
                </tr>
            </thead>
            <tbody>
                @foreach ($subscribers as $subscriber)
                    <tr>
                        <td>{{ $subscriber->id }}</td>
                        <td>{{ $subscriber->name }}</td>
                        <td>{{ $subscriber->email }}</td>
                        <td>
                            <div class="btn-group">
                                @if (Check::can('subscribers', 'update'))
                                    <a href="{{ route('manager.subscribers.edit', $subscriber->id) }}" class="btn btn-small" title="Editar">
                                        <i class="icon-pencil"></i> editar
                                    </a>
                                @endif

                                @if (Check::can('subscribers', 'destroy'))
                                    <a href="{{ route('manager.subscribers.destroy', $subscriber->id) }}" class="btn btn-small" title="Excluir" data-delete>
                                        <i class="icon-trash"></i> excluir
                                    </a>
                                @endif
                            </div>
                        </td>
                    </tr>
                @endforeach
            </tbody>
        </table>

        <div class="pull-left">
            {{ $subscribers->appends(Input::except('page'))->links() }}
        </div><!-- .pull-left -->

        <div class="pull-right">
            <p>Exibindo resultados de {{ $subscribers->getFrom() }} até {{ $subscribers->getTo() }} de um total de {{ $subscribers->getTotal() }}</p>
        </div><!-- .pull-right -->

        <div class="clearfix"></div>
    @endif
@stop
